Package: betaHMM
Type: Package
Title: A Hidden Markov Model Approach for Identifying Differentially
        Methylated Sites and Regions for Beta-Valued DNA Methylation
        Data
Version: 1.9.0
Authors@R: c(person("Koyel","Majumdar",email="koyelmajumdar.phdresearch@gmail.com",
        role=c("cre","aut"),comment = c(ORCID = "0000-0001-6469-488X")),
        person("Romina","Silva",
        role="aut"),
        person("Antoinette Sabrina","Perry",
        role="aut"),
        person("Ronald William","Watson",
        role="aut"),
        person("Isobel Claire","Gorley",email="claire.gormley@ucd.ie",
        role="aut", comment=c(ORCID="0000-0001-7713-681X")),
        person("Thomas Brendan","Murphy",email="brendan.murphy@ucd.ie", 
        role="aut",comment=c(ORCID="0000-0002-5668-7046")),
        person("Florence","Jaffrezic",email="florence.jaffrezic@inrae.fr",
        role="aut"),
        person("Andrea","Rau",email="andrea.rau@inrae.fr",role="aut",
        comment = c(ORCID = "0000-0001-6469-488X")))
Description: A novel approach utilizing a homogeneous hidden Markov model. And
            effectively model untransformed beta values. To identify DMCs while 
            considering the spatial. Correlation of the adjacent CpG sites.
License: GPL-3
Encoding: UTF-8
Imports: stats, ggplot2, scales, methods, pROC, foreach, doParallel,
        parallel, cowplot, dplyr, tidyr, tidyselect, stringr, utils
Depends: R (>= 4.3.0), SummarizedExperiment, S4Vectors, GenomicRanges
RoxygenNote: 7.2.3
biocViews: DNAMethylation, DifferentialMethylation, ImmunoOncology,
        BiomedicalInformatics, MethylationArray, Software,
        MultipleComparison, Sequencing, Spatial, Coverage, GeneTarget,
        HiddenMarkovModel, Microarray
Suggests: rmarkdown, knitr, testthat (>= 3.0.0), BiocStyle
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/betaHMM
git_branch: devel
git_last_commit: a813975
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:30:46 UTC; biocbuild
Author: Koyel Majumdar [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-6469-488X>),
  Romina Silva [aut],
  Antoinette Sabrina Perry [aut],
  Ronald William Watson [aut],
  Isobel Claire Gorley [aut] (ORCID:
    <https://orcid.org/0000-0001-7713-681X>),
  Thomas Brendan Murphy [aut] (ORCID:
    <https://orcid.org/0000-0002-5668-7046>),
  Florence Jaffrezic [aut],
  Andrea Rau [aut] (ORCID: <https://orcid.org/0000-0001-6469-488X>)
Maintainer: Koyel Majumdar <koyelmajumdar.phdresearch@gmail.com>
